# hichipper tests

equivalent to running
```
hichipper --out output1 --peak-pad 1000 --skip-resfrag-pad --skip-qc --skip-diffloop yaml/one.yaml
```

and testing the output against something we think is correct
